@@ -10,4 +10,9 @@ sub new {
 	bless $self, $class;
 }
 
+sub switch {
+	my ($self) = @_;
+
+}
+
 1;
