@@ -5,7 +5,7 @@ use parent 'Token';
 use constant PROGRAMTOKENS => qw(IDENTIFICATION PROGRAM-ID);
 
 sub new {
-	my ($class, $name) = @_;
+	my ($class) = @_;
         my $self = $class->SUPER::new;
 
 	$self->{subTokens}[Cobol::Compiler::ProgramToken->IDENTIFCATION] = 11;
